==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/lib/plugins/usermanager/lang/pl/lang.php <==
<?php
/**
 * polish language file
 *
 * @author Grzegorz Żur <grzegorz.zur@gmail.com>
 */
 
$lang['menu'] = 'Menadżer użytkowników'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(uwierzytelnienie użytkownika niemożliwe)';
$lang['nosupport']   = '(zarządzanie użytkownikami niemożliwe)';

$lang['badauth']     = 'błędny mechanizm uwierzytelniania';     // should never be displayed!

$lang['user_id']     = 'Nazwa użytkownika';
$lang['user_pass']   = 'Hasło';
$lang['user_name']   = 'Użytkownik';
$lang['user_mail']   = 'E-mail';
$lang['user_groups'] = 'Grupy';

$lang['field']       = 'Pole';
$lang['value']       = 'Wartość';
$lang['add']         = 'Dodaj';
$lang['delete']      = 'Usuń';
$lang['delete_selected'] = 'Usuń zaznaczone';
$lang['edit']        = 'Edytuj';
$lang['edit_prompt'] = 'Edytuj użytkownika';
$lang['modify']      = 'Zapisz zmiany';
$lang['search']      = 'Szukaj';
$lang['search_prompt'] = 'Rozpocznij przeszukiwanie';
$lang['clear']       = 'Resetuj filtr przeszukiwania';
$lang['filter']      = 'Filtr';

$lang['summary']     = 'Użytkownicy %1$d-%2$d z %3$d znalezionych. Całkowita ilość użytkowników %4$d.';
$lang['nonefound']   = 'Nie znaleziono użytkowników. Całkowita ilość użytkowników %d.';
$lang['delete_ok']   = 'Usunięto %d użytkowników.';
$lang['delete_fail'] = 'Błąd przy usuwaniu %d użytkowników.';
$lang['update_ok']   = 'Dane użytkownika zostały zmienione!';
$lang['update_fail'] = 'Błąd przy zmianie danych użytkownika!';
$lang['update_exists'] = 'Błąd przy zmianie nazwy użytkownika, użytkownik o tej nazwie (%s) już istnieje (inne zmiany zostały wprowadzone).';

$lang['start']  = 'początek';
$lang['prev']   = 'poprzedni';
$lang['next']   = 'następny';
$lang['last']   = 'ostatni';

==> dokuwiki_0.0.20061106.orig.tar.gz: dokuwiki-2006-11-06/lib/plugins/usermanager/lang/pl/lang.php <==
<?php
/**
 * polish language file
 *
 * @author Grzegorz Żur <grzegorz.zur@gmail.com>
 */
 
$lang['menu'] = 'Menadżer użytkowników'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(uwierzytelnienie użytkownika niemożliwe)';
$lang['nosupport']   = '(zarządzanie użytkownikami niemożliwe)';

$lang['badauth']     = 'błędny mechanizm uwierzytelniania';     // should never be displayed!

$lang['user_id']     = 'Nazwa użytkownika';
$lang['user_pass']   = 'Hasło';
$lang['user_name']   = 'Użytkownik';
$lang['user_mail']   = 'E-mail';
$lang['user_groups'] = 'Grupy';

$lang['field']       = 'Pole';
$lang['value']       = 'Wartość';
$lang['add']         = 'Dodaj';
$lang['delete']      = 'Usuń';
$lang['delete_selected'] = 'Usuń zaznaczone';
$lang['edit']        = 'Edytuj';
$lang['edit_prompt'] = 'Edytuj użytkownika';
$lang['modify']      = 'Zapisz zmiany';
$lang['search']      = 'Szukaj';
$lang['search_prompt'] = 'Rozpocznij przeszukiwanie';
$lang['clear']       = 'Resetuj filtr przeszukiwania';
$lang['filter']      = 'Filtr';

$lang['summary']     = 'Użytkownicy %1$d-%2$d z %3$d znalezionych. Całkowita ilość użytkowników %4$d.';
$lang['nonefound']   = 'Nie znaleziono użytkowników. Całkowita ilość użytkowników %d.';
$lang['delete_ok']   = 'Usunięto %d użytkowników.';
$lang['delete_fail'] = 'Błąd przy usuwaniu %d użytkowników.';
$lang['update_ok']   = 'Dane użytkownika zostały zmienione!';
$lang['update_fail'] = 'Błąd przy zmianie danych użytkownika!';
$lang['update_exists'] = 'Błąd przy zmianie nazwy użytkownika, użytkownik o tej nazwie (%s) już istnieje (inne zmiany zostały wprowadzone).';

$lang['start']  = 'początek';
$lang['prev']   = 'poprzedni';
$lang['next']   = 'następny';
$lang['last']   = 'ostatni';

// added after 2006-03-09 release
$lang['edit_usermissing'] = 'Nie znaleziono wybranego użytkownika, nazwa użytkownika mogła zostać zmieniona lub usunięta.';
